{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "ChIP-seq 01 QC - reads: PE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Adapters file",
                    "type": "File",
                    "id": "#main/default_adapters_file"
                },
                {
                    "doc": "Input read1 fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_read1_fastq_files"
                },
                {
                    "doc": "Input read2 fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_read2_fastq_files"
                },
                {
                    "doc": "Number of threads.",
                    "type": "int",
                    "id": "#main/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#diff.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/compare_read_counts_read1/file1",
                        "#main/compare_read_counts_read1/file2"
                    ],
                    "in": [
                        {
                            "source": "#main/count_raw_reads_read1/output_read_count",
                            "id": "#main/compare_read_counts_read1/file1"
                        },
                        {
                            "source": "#main/count_fastqc_reads_read1/output_fastqc_read_count",
                            "id": "#main/compare_read_counts_read1/file2"
                        }
                    ],
                    "out": [
                        "#main/compare_read_counts_read1/result"
                    ],
                    "id": "#main/compare_read_counts_read1"
                },
                {
                    "run": "#diff.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/compare_read_counts_read2/file1",
                        "#main/compare_read_counts_read2/file2"
                    ],
                    "in": [
                        {
                            "source": "#main/count_raw_reads_read2/output_read_count",
                            "id": "#main/compare_read_counts_read2/file1"
                        },
                        {
                            "source": "#main/count_fastqc_reads_read2/output_fastqc_read_count",
                            "id": "#main/compare_read_counts_read2/file2"
                        }
                    ],
                    "out": [
                        "#main/compare_read_counts_read2/result"
                    ],
                    "id": "#main/compare_read_counts_read2"
                },
                {
                    "run": "#count-fastqc-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_fastqc_reads_read1/input_fastqc_data",
                        "#main/count_fastqc_reads_read1/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read1/basename",
                            "id": "#main/count_fastqc_reads_read1/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data_read1/output_fastqc_data_file",
                            "id": "#main/count_fastqc_reads_read1/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/count_fastqc_reads_read1/output_fastqc_read_count"
                    ],
                    "id": "#main/count_fastqc_reads_read1"
                },
                {
                    "run": "#count-fastqc-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_fastqc_reads_read2/input_fastqc_data",
                        "#main/count_fastqc_reads_read2/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read2/basename",
                            "id": "#main/count_fastqc_reads_read2/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data_read2/output_fastqc_data_file",
                            "id": "#main/count_fastqc_reads_read2/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/count_fastqc_reads_read2/output_fastqc_read_count"
                    ],
                    "id": "#main/count_fastqc_reads_read2"
                },
                {
                    "run": "#count-fastq-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_raw_reads_read1/input_fastq_file",
                        "#main/count_raw_reads_read1/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read1/basename",
                            "id": "#main/count_raw_reads_read1/input_basename"
                        },
                        {
                            "source": "#main/input_read1_fastq_files",
                            "id": "#main/count_raw_reads_read1/input_fastq_file"
                        }
                    ],
                    "out": [
                        "#main/count_raw_reads_read1/output_read_count"
                    ],
                    "id": "#main/count_raw_reads_read1"
                },
                {
                    "run": "#count-fastq-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_raw_reads_read2/input_fastq_file",
                        "#main/count_raw_reads_read2/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read2/basename",
                            "id": "#main/count_raw_reads_read2/input_basename"
                        },
                        {
                            "source": "#main/input_read2_fastq_files",
                            "id": "#main/count_raw_reads_read2/input_fastq_file"
                        }
                    ],
                    "out": [
                        "#main/count_raw_reads_read2/output_read_count"
                    ],
                    "id": "#main/count_raw_reads_read2"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#main/extract_basename_read1/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/extract_basename_read1/do_not_escape_sep"
                        },
                        {
                            "source": "#main/input_read1_fastq_files",
                            "valueFrom": "$(self.basename)",
                            "id": "#main/extract_basename_read1/file_path"
                        },
                        {
                            "valueFrom": "(\\.fastq.gz|\\.fastq)",
                            "id": "#main/extract_basename_read1/sep"
                        }
                    ],
                    "out": [
                        "#main/extract_basename_read1/basename"
                    ],
                    "id": "#main/extract_basename_read1"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#main/extract_basename_read2/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/extract_basename_read2/do_not_escape_sep"
                        },
                        {
                            "source": "#main/input_read2_fastq_files",
                            "valueFrom": "$(self.basename)",
                            "id": "#main/extract_basename_read2/file_path"
                        },
                        {
                            "valueFrom": "(\\.fastq.gz|\\.fastq)",
                            "id": "#main/extract_basename_read2/sep"
                        }
                    ],
                    "out": [
                        "#main/extract_basename_read2/basename"
                    ],
                    "id": "#main/extract_basename_read2"
                },
                {
                    "run": "#extract_fastqc_data.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/extract_fastqc_data_read1/input_qc_report_file",
                        "#main/extract_fastqc_data_read1/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read1/basename",
                            "id": "#main/extract_fastqc_data_read1/input_basename"
                        },
                        {
                            "source": "#main/fastqc_read1/output_qc_report_file",
                            "id": "#main/extract_fastqc_data_read1/input_qc_report_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastqc_data_read1/output_fastqc_data_file"
                    ],
                    "id": "#main/extract_fastqc_data_read1"
                },
                {
                    "run": "#extract_fastqc_data.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/extract_fastqc_data_read2/input_qc_report_file",
                        "#main/extract_fastqc_data_read2/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename_read2/basename",
                            "id": "#main/extract_fastqc_data_read2/input_basename"
                        },
                        {
                            "source": "#main/fastqc_read2/output_qc_report_file",
                            "id": "#main/extract_fastqc_data_read2/input_qc_report_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastqc_data_read2/output_fastqc_data_file"
                    ],
                    "id": "#main/extract_fastqc_data_read2"
                },
                {
                    "run": "#fastqc.cwl",
                    "scatter": "#main/fastqc_read1/input_fastq_file",
                    "in": [
                        {
                            "source": "#main/input_read1_fastq_files",
                            "id": "#main/fastqc_read1/input_fastq_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/fastqc_read1/threads"
                        }
                    ],
                    "out": [
                        "#main/fastqc_read1/output_qc_report_file"
                    ],
                    "id": "#main/fastqc_read1"
                },
                {
                    "run": "#fastqc.cwl",
                    "scatter": "#main/fastqc_read2/input_fastq_file",
                    "in": [
                        {
                            "source": "#main/input_read2_fastq_files",
                            "id": "#main/fastqc_read2/input_fastq_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/fastqc_read2/threads"
                        }
                    ],
                    "out": [
                        "#main/fastqc_read2/output_qc_report_file"
                    ],
                    "id": "#main/fastqc_read2"
                },
                {
                    "run": "#overrepresented_sequence_extract.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/overrepresented_sequence_extract_read1/input_fastqc_data",
                        "#main/overrepresented_sequence_extract_read1/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/default_adapters_file",
                            "id": "#main/overrepresented_sequence_extract_read1/default_adapters_file"
                        },
                        {
                            "source": "#main/extract_basename_read1/basename",
                            "id": "#main/overrepresented_sequence_extract_read1/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data_read1/output_fastqc_data_file",
                            "id": "#main/overrepresented_sequence_extract_read1/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/overrepresented_sequence_extract_read1/output_custom_adapters"
                    ],
                    "id": "#main/overrepresented_sequence_extract_read1"
                },
                {
                    "run": "#overrepresented_sequence_extract.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/overrepresented_sequence_extract_read2/input_fastqc_data",
                        "#main/overrepresented_sequence_extract_read2/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/default_adapters_file",
                            "id": "#main/overrepresented_sequence_extract_read2/default_adapters_file"
                        },
                        {
                            "source": "#main/extract_basename_read2/basename",
                            "id": "#main/overrepresented_sequence_extract_read2/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data_read2/output_fastqc_data_file",
                            "id": "#main/overrepresented_sequence_extract_read2/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/overrepresented_sequence_extract_read2/output_custom_adapters"
                    ],
                    "id": "#main/overrepresented_sequence_extract_read2"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/count_raw_reads_read1/output_read_count",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_count_raw_reads_read1"
                },
                {
                    "outputSource": "#main/count_raw_reads_read2/output_read_count",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_count_raw_reads_read2"
                },
                {
                    "outputSource": "#main/overrepresented_sequence_extract_read1/output_custom_adapters",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_custom_adapters_read1"
                },
                {
                    "outputSource": "#main/overrepresented_sequence_extract_read2/output_custom_adapters",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_custom_adapters_read2"
                },
                {
                    "outputSource": "#main/compare_read_counts_read1/result",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_diff_counts_read1"
                },
                {
                    "outputSource": "#main/compare_read_counts_read2/result",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_diff_counts_read2"
                },
                {
                    "doc": "FastQC data files for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/extract_fastqc_data_read1/output_fastqc_data_file",
                    "id": "#main/output_fastqc_data_files_read1"
                },
                {
                    "doc": "FastQC data files for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/extract_fastqc_data_read2/output_fastqc_data_file",
                    "id": "#main/output_fastqc_data_files_read2"
                },
                {
                    "doc": "FastQC reports in zip format for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqc_read1/output_qc_report_file",
                    "id": "#main/output_fastqc_report_files_read1"
                },
                {
                    "doc": "FastQC reports in zip format for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqc_read2/output_qc_report_file",
                    "id": "#main/output_fastqc_report_files_read2"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts read count from fastqc_data.txt",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastqc-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastqc-reads.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc-read_count.txt')"
                    },
                    "id": "#count-fastqc-reads.cwl/output_fastqc_read_count"
                }
            ],
            "baseCommand": "count-fastqc_data-reads.sh",
            "stdout": "$(inputs.input_basename + '.fastqc-read_count.txt')",
            "id": "#count-fastqc-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compares 2 files",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--brief",
                        "position": 3
                    },
                    "id": "#diff.cwl/brief"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#diff.cwl/file1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#diff.cwl/file2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    },
                    "id": "#diff.cwl/result"
                }
            ],
            "baseCommand": "diff",
            "stdout": "stdout.txt",
            "id": "#diff.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Unzips a zipped fastqc report and returns the fastqc_data.txt file. Unzips the file to pipe and uses redirection",
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "*/fastqc_data.txt",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#extract_fastqc_data.cwl/extract_pattern"
                },
                {
                    "type": "string",
                    "id": "#extract_fastqc_data.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#extract_fastqc_data.cwl/input_qc_report_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-p",
                        "position": 1
                    },
                    "id": "#extract_fastqc_data.cwl/pipe"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc_data.txt')"
                    },
                    "id": "#extract_fastqc_data.cwl/output_fastqc_data_file"
                }
            ],
            "baseCommand": "unzip",
            "stdout": "$(inputs.input_basename + '.fastqc_data.txt')",
            "id": "#extract_fastqc_data.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "fastq",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--format"
                    },
                    "id": "#fastqc.cwl/format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fastqc.cwl/input_fastq_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--noextract",
                        "position": 2
                    },
                    "id": "#fastqc.cwl/noextract"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--threads"
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fastq_file.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.gz$/, '').replace(/\\.[^/.]+$/, '') + \"_fastqc.zip\")"
                    },
                    "id": "#fastqc.cwl/output_qc_report_file"
                }
            ],
            "baseCommand": "fastqc",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--dir",
                    "position": 5
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o",
                    "position": 5
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "reddylab/overrepresented_sequence_extract:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Adapters file in fasta format",
                    "id": "#overrepresented_sequence_extract.cwl/default_adapters_file"
                },
                {
                    "type": "string",
                    "doc": "Name of the sample - used as a base name for generating output files",
                    "id": "#overrepresented_sequence_extract.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "fastqc_data.txt file from a fastqc report",
                    "id": "#overrepresented_sequence_extract.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.custom_adapters.fasta')"
                    },
                    "id": "#overrepresented_sequence_extract.cwl/output_custom_adapters"
                }
            ],
            "baseCommand": "overrepresented_sequence_extract.py",
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_basename + '.custom_adapters.fasta')",
                    "position": 3
                }
            ],
            "id": "#overrepresented_sequence_extract.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#basename.cwl/do_not_escape_sep"
                },
                {
                    "type": "string",
                    "id": "#basename.cwl/file_path"
                },
                {
                    "type": "int",
                    "default": 1,
                    "doc": "Number of file extensions to remove",
                    "id": "#basename.cwl/num_ext"
                },
                {
                    "type": "string",
                    "doc": "File extension delimiter",
                    "id": "#basename.cwl/sep"
                }
            ],
            "expression": "${\n  var sep_escaped = !inputs.do_not_escape_sep ? inputs.sep.replace(/[^\\w\\s]/g, \"\\\\$&\") : inputs.sep;\n  var out=inputs.file_path.replace(/^.*[\\\\\\/]/, '');\n  for (var e=0;e<inputs.num_ext; e++){\n    out=out.split(RegExp(\"\\\\b\" + sep_escaped + \"\\\\b\"))[0];\n  }\n  return {\"basename\": out};\n}\n",
            "outputs": [
                {
                    "type": "string",
                    "id": "#basename.cwl/basename"
                }
            ],
            "id": "#basename.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts reads in a fastq file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastq-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastq-reads.cwl/input_fastq_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.read_count.txt')"
                    },
                    "id": "#count-fastq-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": "count-fastq-reads.sh",
            "stdout": "$(inputs.input_basename + '.read_count.txt')",
            "id": "#count-fastq-reads.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
